@@ -424,8 +424,9 @@ typedef struct knh_sfp_t {
 		return; \
 	}\
 
-#define KNH_ITRNEXT(ctx, sfp, n, v) {\
-		KNH_MOV(ctx, sfp[n].o, v);\
+#define KNH_ITRNEXT(ctx, sfp, i, v) {\
+		KNH_MOV(ctx, sfp[i].o, v);\
+		sfp[i].data = ((Int*)v)->n.data;\
 		return; \
 	}\
 
@@ -450,6 +451,7 @@ typedef struct knh_sfp_t {
 
 #define KNH_MAPPED(ctx, sfp, v) {\
 		KNH_MOV(ctx, sfp[0].o, v);\
+		sfp[0].data = ((Int*)v)->n.data;\
 		return; \
 	}\
 
