@@ -28,7 +28,10 @@
 /* ************************************************************************ */
 
 #include<konoha.h>
+#define KNH_PKGNAME "math"
+
 #ifdef KNH_USING_MATH
+#define _USE_MATH_DEFINES     /* needed in Windows */
 #include<math.h>    /* @using math -lm */
 #endif
 
@@ -47,7 +50,7 @@ extern "C" {
 static
 METHOD knh__Math_sin(Ctx *ctx, knh_sfp_t *sfp)
 {
-	KNH_RETURN_Float(ctx, sfp, sin(ARG_double(sfp[1])));
+	KNH_RETURN_Float(ctx, sfp, sin(p_double(sfp[1])));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -56,24 +59,38 @@ METHOD knh__Math_sin(Ctx *ctx, knh_sfp_t *sfp)
 static
 METHOD knh__Math_abs(Ctx *ctx, knh_sfp_t *sfp)
 {
-	KNH_RETURN_Float(ctx, sfp, fabs(ARG_double(sfp[1])));
+	KNH_RETURN_Float(ctx, sfp, fabs(p_double(sfp[1])));
 }
 
 #endif/*KNH_USING_MATH*/
 
+
+static int testnum(int n) {
+	return n;
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method Int! Math.succ(Int! n) */
+
+static
+METHOD knh__Math_testnum(Ctx *ctx, knh_sfp_t *sfp)
+{
+	KNH_RETURN_Int(ctx, sfp, testnum(p_int(sfp[1])));
+}
+
 /* ======================================================================== */
 /* [KNHAPI] */
 
-KNHAPI(void) knhmath_traverse(Ctx *ctx, f_traverse ftr)
+void knhmath_traverse(Ctx *ctx, knh_ftraverse ftr)
 {
-	if(konoha_issweep(ftr)) {
-
-	}
+//	if(konoha_issweep(ftr)) {
+//
+//	}
 }
 
 /* ------------------------------------------------------------------------ */
 
-KNHAPI(int) knhmath_init(Ctx *ctx)
+int knhmath_init(Ctx *ctx)
 {
 #ifdef KNH_USING_MATH
 	KNH_NOTICE(ctx, "loading math..");
@@ -82,6 +99,7 @@ KNHAPI(int) knhmath_init(Ctx *ctx)
 	konoha_addMethod(ctx, "float Math.sin(float v)", knh__Math_sin);
 	konoha_addFloatConst(ctx, "Math.PI", (knh_float_t)M_PI);
 	konoha_addFloatConst(ctx, "Math.E", (knh_float_t)M_E);
+	konoha_addMethod(ctx, "int Math.testnum(int n)", knh__Math_testnum);
 	return 1;
 #else
 	return 0;
@@ -90,6 +108,24 @@ KNHAPI(int) knhmath_init(Ctx *ctx)
 
 /* ------------------------------------------------------------------------ */
 
+static knh_pkgmeta_t PKGDATA = {
+	KONOHA_BUILDID, /* Don't change this */
+	KNH_PKGNAME,    /* package name (not NULL) */
+	"1.0",  /* package version (not NULL) */
+	NULL,   /* additional information */
+	KONOHA_URLBASE "package.math", /* URL */
+	knhmath_init,
+	knhmath_traverse,
+	NULL
+};
+
+KNH_EXPORTS(knh_pkgmeta_t*) knhmath_load(Ctx *ctx)
+{
+	return &(PKGDATA);
+}
+
+/* ------------------------------------------------------------------------ */
+
 #ifdef __cplusplus
 }
 #endif
