@@ -1895,7 +1895,9 @@ knh_labelid_t knh_Asm_pushLabelStack(Ctx *ctx, Asm *abr, Stmt *stmt)
 {
 	Token *ltk = knh_StmtMETA_getLabel(ctx, stmt);
 	if(IS_NULL(ltk)) {
-		ltk = new_TokenCONST(ctx, FL(stmt), UP(TS_EMPTY));
+		char lbn[8];
+		knh_snprintf(lbn, sizeof(lbn), "%d", DP(abr)->llstep);
+		ltk = new_TokenCONST(ctx, FL(stmt), UP(new_String(ctx, B(lbn), NULL)));
 		SP(ltk)->tt = TT_LABEL;
 	}
 	else {
@@ -1905,6 +1907,7 @@ knh_labelid_t knh_Asm_pushLabelStack(Ctx *ctx, Asm *abr, Stmt *stmt)
 	knh_Array_add(ctx, DP(abr)->lstacks, UP(ltk));
 	knh_labelid_t labelid = knh_Asm_newLabelId(ctx, abr, ltk);
 	knh_labelid_t labelid2 = knh_Asm_newLabelId(ctx, abr, NULL);
+	DBG2_P("label L1, L2 = %d, %d", labelid, labelid2);
 	KNH_ASSERT(labelid + 1 == labelid2);
 	return labelid;
 }
@@ -2404,6 +2407,7 @@ void KNH_ASM_METHOD(Ctx *ctx, Asm *abr, Method *mtd, Stmt *params, Stmt *body, i
 
 void knh_StmtMETHOD_asm(Ctx *ctx, Stmt *stmt, Asm *abr)
 {
+	if(DP(stmt)->size == 4) return;
 	Method *mtd = DP(StmtMETHOD_method(stmt))->mtd;
 	KNH_ASM_METHOD(ctx, abr, mtd, DP(stmt)->stmts[3], StmtMETHOD_instmt(stmt), 1 /*Iteration */);
 }
