@@ -1131,6 +1131,9 @@ Term * knh_StmtDECL_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		}
 		else {
 			knh_StmtDECL_toLET(ctx, stmt);
+			if(!TERMs_typing(ctx, stmt, 0, abr, ns, TYPE_Any, TWARN_)) {
+				return NULL;
+			}
 		}
 	}
 	else if(level == 1) { /* FIELD VARIABLE */
@@ -1174,6 +1177,9 @@ Term * knh_StmtDECL_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		else {
 			knh_Asm_declareVariable(ctx, abr, flag, type, fn, value);
 			knh_StmtDECL_toLET(ctx, stmt);
+			if(!TERMs_typing(ctx, stmt, 0, abr, ns, TYPE_Any, TWARN_)) {
+				return NULL;
+			}
 		}
 	}
 	return TM(stmt);
@@ -1626,7 +1632,25 @@ Term *knh_StmtNEW_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_clas
 
 	knh_class_t mtd_cid = knh_Token_getcid(ctx, DP(stmt)->tokens[1], ns, CLASS_unknown);
 	if(mtd_cid == CLASS_Exception) {
+		Token *mtk = new_TokenCONST(ctx, FL(stmt), DP(DP(stmt)->tokens[1])->data);
 		mn = METHODN_new__init;
+		if(DP(stmt)->size == 2) {
+			knh_Stmt_add(ctx, stmt, mtk);
+		}
+		else if(DP(stmt)->size == 3) {
+			knh_Stmt_add(ctx, stmt, DP(stmt)->tokens[2]);
+			KNH_SETv(ctx, DP(stmt)->terms[2], mtk);
+		}
+		else if(DP(stmt)->size == 4) {
+			knh_Stmt_add(ctx, stmt, DP(stmt)->tokens[3]);
+			KNH_SETv(ctx, DP(stmt)->terms[3], DP(stmt)->terms[2]);
+			KNH_SETv(ctx, DP(stmt)->terms[2], mtk);
+		}
+		else {
+			KNH_SETv(ctx, DP(stmt)->terms[4], DP(stmt)->terms[3]);
+			KNH_SETv(ctx, DP(stmt)->terms[3], DP(stmt)->terms[2]);
+			KNH_SETv(ctx, DP(stmt)->terms[2], mtk);
+		}
 	}
 
 	if(mtd_cid == CLASS_unknown) {
@@ -2854,13 +2878,12 @@ Term * knh_StmtMETHOD_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	}
 	{
 		DBG2_(knh_Method__dump(ctx, mtd, KNH_STDOUT, (String*)KNH_NULL););
+		knh_Token_setCONST(ctx, StmtMETHOD_method(stmt), UP(mtd));
 		if(DP(stmt)->size == 4) {
 			DEBUG3("@Abstract");
-			knh_Stmt_done(ctx, stmt);
 		}
 		else {
 			knh_Stmt_checkLastReturn(ctx, StmtMETHOD_instmt(stmt), mtd);
-			knh_Token_setCONST(ctx, StmtMETHOD_method(stmt), UP(mtd));
 		}
 		return TM(stmt);
 	}
@@ -2996,6 +3019,7 @@ Term *knh_Stmt_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_type_t
 			if(!TERMs_typingBLOCK(ctx, stmt, 0, abr, ns)) {
 				return NULL;
 			}
+			return TM(stmt);
 		case STT_DECL:
 			return knh_StmtDECL_typing(ctx, stmt, abr, ns);
 		case STT_IF:
